@@ -110,21 +110,16 @@ class FileUtils:
         return os.path.exists(target)
 
     @classmethod
-    def gbk_to_utf8(cls, source, target, callback_line=None, callback_file=None):
+    def gbk_to_utf8(cls, source, target, callback=None):
         """
-        Convert a file from GBK to UTF-8.
-        :param source:
+        Convert GBK to UTF-8.
         :param target:
-        :param callback_line:
-        :param callback_file:
-        :return: dst file
+        :param callback:
+        :return:
         """
         with open(source, "r", encoding="gbk") as src:
-            with open(target, "rw", encoding="utf-8") as dst:
+            with open(target, "w", encoding="utf-8") as dst:
                 for line in src.readlines():
-                    if callback_line:
-                        line = callback_line(line)
+                    if callback:
+                        line = callback(line)
                     dst.write(line)
-                if callback_file:
-                    return callback_file(dst)
-                return dst
